package com.dayou.controller;

import com.dayou.dto.TaskRecordDTO;
import com.dayou.workflow.annotation.FinishTask;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.web.bind.annotation.RestController;
import com.dayou.controller.BaseController;
import com.dayou.service.IAssetsProductionService;
import com.dayou.entity.AssetsProduction;
import com.dayou.common.RestResponse;
import org.springframework.web.bind.annotation.*;
import com.dayou.utils.ConvertUtil;
import com.dayou.utils.HttpKit;
import com.dayou.exception.ErrorCode;
import java.util.Date;
import java.util.List;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import org.springframework.http.MediaType;
import org.springframework.web.multipart.MultipartFile;
/**
 * 资产产品表
 *
 * @author GouGengquan
 * @since 2024-03-28
 */
@RestController
@RequestMapping("assetsProduction")
@Slf4j
public class AssetsProductionController extends BaseController {
    @Autowired
    private IAssetsProductionService assetsProductionService;

    /**
     * 根据资产业务id查询资产业务产品
     * @param id 资产业务id
     * @return RestResponse<List<AssetsProduction>>
     */
    @GetMapping("getAroductionByAssetsId/{id}")
    public RestResponse<List<AssetsProduction>> getAroductionByAssetsId(@PathVariable Long id) {
        return RestResponse.data(assetsProductionService.getAroductionByAssetsId(id));
    }

    /**
    * 资产产品表列表
    */
    @GetMapping("")
    public RestResponse<Page<AssetsProduction>> page(AssetsProduction assetsProduction, Page page){
        Page<AssetsProduction> pages=assetsProductionService.selectPage(page,assetsProduction);
        return RestResponse.data(pages);
    }

    /**
     * 资产产品表详情
     */
    @GetMapping("/{id}")
    public RestResponse<AssetsProduction> detail(@PathVariable Long id){
        AssetsProduction xAssetsProduction =assetsProductionService.detail(id);
        return RestResponse.data(xAssetsProduction);
     }

    /**
     * 资产产品表新增
     */
    @FinishTask
    @PostMapping("/save")
    public RestResponse<Boolean> save(@RequestBody TaskRecordDTO<AssetsProduction> taskRecordDTO) {
        Boolean ret = assetsProductionService.add(taskRecordDTO);
        return RestResponse.data(ret);
    }

    /**
     * 资产产品表更新
     */
    @PutMapping("/update")
    public RestResponse<Boolean> update(@RequestBody AssetsProduction assetsProduction) {
        Boolean ret = assetsProductionService.update(assetsProduction);
        return RestResponse.data(ret);
    }

    /**
     * 资产产品表删除
     */
    @DeleteMapping("/{id}")
    public RestResponse<Boolean> delete(@PathVariable Long id) {
        Boolean ret = assetsProductionService.delete(id);
        return RestResponse.data(ret);
    }

    /**
     * 根据业务id获取产品信息类型集合
     * @param id 资产业务id
     * @return List<String>
     */
    @GetMapping("/getProductionTypes/{id}")
    public RestResponse<List<String>> getProductionTypes(@PathVariable Long id){
        return RestResponse.data(assetsProductionService.getProductionTypes(id));
    }

    /**
     * 根据业务id获取已选择产品
     * @param businessId 资产业务id
     * @return AssetsProduction
     */
    @GetMapping("/getProductionByBusinessId/{businessId}")
    public RestResponse<AssetsProduction> getProductionByBusinessId(@PathVariable Long businessId) {
        return RestResponse.data(assetsProductionService.getProductionByBusinessId(businessId));
    }

}

