package com.dayou.mapper;

import com.dayou.entity.AssetsProduction;
import com.dayou.dao.CustomBaseMapper;
import org.apache.ibatis.annotations.Param;

import java.util.List;

/**
 * <p>
 * 资产产品表 Mapper 接口
 * </p>
 *
 * @author GouGengquan
 * @since 2024-03-28
 */
public interface AssetsProductionMapper extends CustomBaseMapper<AssetsProduction> {

    /**
     * 根据业务id获取产品信息类型集合
     * @param businessId 资产业务id
     * @return List<String>
     */
    List<String> getProductionTypes(@Param("businessId") Long businessId);

    /**
     * 根据业务id获取已选择产品
     * @param businessId 资产业务id
     * @return AssetsProduction
     */
    AssetsProduction getProductionByBusinessId(@Param("businessId") Long businessId);

    /**
     * 获取产品号集合(用于判断下一个子号)
     * @param businessId 业务id
     * @param productionType 产品类型
     * @return List<String>
     */
    List<String> getgetProductionNo(@Param("businessId") Long businessId, @Param("productionType") String productionType);

    /**
     * 跟新产品的产品号信息
     * @param businessId 业务id
     * @param productionType 产品类型
     * @param productionNo 产品号
     * @return Boolean
     */
    Boolean updateProductionNo(@Param("businessId") Long businessId, @Param("productionType") String productionType, @Param("productionNo") String productionNo);

    /**
     * 取子号情况下,再复制一份产品信息并添加
     * @param businessId 业务id
     * @param productionType 产品类型
     * @param printCount 打印数量
     * @return Boolean
     */
    Boolean copyProductionInfo(@Param("businessId") Long businessId, @Param("productionType") String productionType, @Param("printCount") Integer printCount);

}
